PDFNames class final

Collection of names used in PDF files

Annotations
  • @immutable

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

a → const PDFName
alternate → const PDFName
annots → const PDFName
artBox → const PDFName
ascii85Decode → const PDFName
author → const PDFName
b → const PDFName
bbox → const PDFName
bitsPerComponent → const PDFName
bleedBox → const PDFName
bm → const PDFName
CA → const PDFName
ca → const PDFName
catalog → const PDFName
colors → const PDFName
colorSpace → const PDFName
columns → const PDFName
contents → const PDFName
count → const PDFName
creationDate → const PDFName
creator → const PDFName
cropBox → const PDFName
d → const PDFName
dctDecode → const PDFName
decode → const PDFName
decodeParms → const PDFName
dest → const PDFName
deviceCMYK → const PDFName
deviceGray → const PDFName
deviceRGB → const PDFName
encoding → const PDFName
extend → const PDFName
extGState → const PDFName
filter → const PDFName
first → const PDFName
flateDecode → const PDFName
font → const PDFName
form → const PDFName
group → const PDFName
height → const PDFName
iccBased → const PDFName
id → const PDFName
image → const PDFName
imageB → const PDFName
imageC → const PDFName
index → const PDFName
indexed → const PDFName
info → const PDFName
intent → const PDFName
keywords → const PDFName
kids → const PDFName
lang → const PDFName
length → const PDFName
matrix → const PDFName
mediaBox → const PDFName
metadata → const PDFName
modDate → const PDFName
n → const PDFName
name → const PDFName
next → const PDFName
objStm → const PDFName
ocg → const PDFName
ocgs → const PDFName
ocProperties → const PDFName
off → const PDFName
on → const PDFName
order → const PDFName
outlines → const PDFName
page → const PDFName
pages → const PDFName
parent → const PDFName
pdf → const PDFName
predictor → const PDFName
prev → const PDFName
procSet → const PDFName
producer → const PDFName
properties → const PDFName
resources → const PDFName
root → const PDFName
rotate → const PDFName
s → const PDFName
size → const PDFName
sMask → const PDFName
structParents → const PDFName
subject → const PDFName
subtype → const PDFName
text → const PDFName
title → const PDFName
transparency → const PDFName
trimBox → const PDFName
type → const PDFName
usage → const PDFName
version → const PDFName
w → const PDFName
width → const PDFName
xml → const PDFName
xObject → const PDFName
xRef → const PDFName