readBuffer abstract method

Future<int> readBuffer(
  1. int count,
  2. Uint8List into
)

Attempts to read count bytes from the stream into into. Returns the number of bytes read (which can be < count if the end of the stream has been reached).

Implementation

Future<int> readBuffer(int count, Uint8List into);