PDFParser class
Parses a PDF document from a RandomAccessStream.
Constructors
- PDFParser(RandomAccessStream _buffer)
-
Creates a new PDF parser which uses the given
_bufferClosing the buffer will cause the returned PDFDocument to be in an indeterminate state.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
parse(
{bool cacheObjectsHint = true}) → Future< PDFDocument> -
Parses the PDF document from the stream
The document is lazily parsed, only the absolute minimum is parsed, other
items are parsed on demand. This means closing the stream will break
reading items in the returned PDFDocument.
Setting
cacheObjectsHinttotruewill cache resolved objects in memory -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited